#
# spec file for package libwpg
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libwpg-0_3-3
Name:           libwpg
Version:        0.3.4
Release:        2.6
Summary:        Library to read and parse graphics in WordPerfect Graphics format
License:        LGPL-2.1-or-later AND MPL-2.0
Group:          Productivity/Publishing/Word
URL:            http://libwpg.sourceforge.net/
Source:         http://downloads.sourceforge.net/project/%{name}/%{name}/%{name}-%{version}/%{name}-%{version}.tar.xz
BuildRequires:  boost-devel
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  help2man
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(librevenge-0.0) >= 0.0.0
BuildRequires:  pkgconfig(libwpd-0.10) >= 0.10.0

%description
libwpg is a C++ library to read and parse graphics in WPG (WordPerfect
Graphics) format. It is cross-platform, at the moment it can be build
on Microsoft Windows and Linux.

%package -n %{libname}
Summary:        Library to read and parse graphics in WordPerfect Graphics format
Group:          System/Libraries

%description -n %{libname}
libwpg is a C++ library to read and parse graphics in WPG (WordPerfect
Graphics) format.

%package devel
Summary:        Files for Developing with libwpg
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
libwpg is a C++ library to read and parse graphics in WPG (WordPerfect
Graphics) format. It is cross-platform, at the moment it can be build
on Microsoft Windows and Linux.

This package contains the libwpg development files.

%package devel-doc
Summary:        Documentation for the libwpg API
Group:          Documentation/HTML
BuildArch:      noarch

%description devel-doc
This package contains documentation for the libwpg API.

%package tools
Summary:        Tools for converting WordPerfect Graphics files
Group:          Productivity/Publishing/Word

%description tools
Tools to work with graphics in WPG (WordPerfect Graphics) format.

%prep
%setup -q

%build
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
%configure \
	--disable-silent-rules \
	--disable-werror \
	--disable-static \
	--docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# manpages
mkdir -p %{buildroot}%{_mandir}/man1
for i in wpg2raw wpg2svg; do
	LD_LIBRARY_PATH=%{buildroot}%{_libdir} \
	help2man -N -o %{buildroot}%{_mandir}/man1/$i.1 %{buildroot}%{_bindir}/$i
done
# documentation
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -p AUTHORS COPYING.LGPL COPYING.MPL ChangeLog %{buildroot}%{_docdir}/%{name}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/*.so.*

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/libwpg*.pc
%{_includedir}/libwpg-*

%files devel-doc
%doc %{_docdir}/%{name}/html

%files tools
%{_bindir}/*
%{_mandir}/man1/*.1*
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/[A-Z]*

%changelog
* Sat Apr 29 2023 Fridrich Strba <fstrba@suse.com>
- Update to 0.3.4
  * WPG2: Incomplete implementation of handlePenForeColor
    (tdf#155057)
  * Correct a problem concerning HAVE_VISIBILITY not defined when
    compiling for Windows...
  * WPG1: fix vertical position of text line
  * WPG1: improve output of aligned text
  * WPG1: handle font size
  * WPG1: parse more graphic text attrs
  * WPG1: make text type 2 handler build again
  * Add note for text position
  * WPG1: handle text color
  * WPG1: parse some bits of text attrs record
  * Drop pointless cast
  * WPG1: handle line style
  * Drop a pointless cast
  * WPG1: parse page format record
  * WPG1: handle groups
  * Fix too small loop variables
* Fri Jan 28 2022 Fridrich Strba <fstrba@suse.com>
- Fix license header to correspond SPDX abbreviation
* Sat Aug 15 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.3.3:
  - Drop obsolete MSVC project files.
  - Use --disable-werror instead of --enable-werror as configure
    default.
  - Fix parsing of 24-bit RGB and 32-bit RGBA bitmaps in WPG2 files.
    (tdf#78105)
* Thu Sep 14 2017 tchvatal@suse.com
- Remove requires that are not needed on the devel pkg
* Wed Sep 13 2017 tchvatal@suse.com
- Version bump to 0.3.2:
  * Require C++11 for build.
  * Fix a couple of issues found by oss-fuzz.
  * Improve performance of reading image data from WPG2 files.
  * Various minor code cleanups.
* Wed Dec 30 2015 fstrba@suse.com
- Generate manpages for the binaries in libwpg-tools
* Sat Dec 26 2015 fstrba@suse.com
- Version bump to 0.3.1:
  * Fix crash when NULL is passed as input stream.
  * Use symbol visibility on Linux. The library only exports public
    functions now.
  * Fix various crashes and hangs when reading broken files found
    with the help of american-fuzzy-lop.
  * Fix some warnings found by Coverity.
  * Make --help output of all command line tools more
    help2man-friendly.
* Wed Jun 11 2014 tchvatal@suse.com
- Version bump to 0.3.0:
  * New release based on librevenge framework
  * Variouf fixes and cleanups
* Sat Jan 25 2014 tchvatal@suse.com
- Cleanup with spec-cleaner and noarch the documentation.
* Fri Nov  1 2013 tchvatal@suse.com
- Use verbose build, disable werror, drop conditional for docs.
* Fri Apr 19 2013 fridrich.strba@suse.com
- Upgrade to upstream 0.2.1
  - Add MPL 2.0+ as license under which libwpg is distributed
  - Numerous coverity fixes
- Remove integrated patch
* Tue Apr 16 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Tue Jan 24 2012 jengelh@medozas.de
- Remove redundant tags/sections (see specfile guidelines)
- SPDX-style license field
- Parallel build with %%_smp_mflags
- Adjust rpm group of -tools and (main) to match libwpd
* Mon Jan 23 2012 crrodriguez@opensuse.org
- Build with -fvisibility-inlines-hidden
* Tue Oct  4 2011 fridrich.strba@suse.com
- Upgrade to upstream 0.2.1
  - Improvement of line styles and
  - General conversion fidelity
* Mon May 23 2011 crrodriguez@opensuse.org
- Do not include build dates in documentation, messes up build-compare
* Tue Dec  7 2010 fstrba@novell.com
- Upgrade to a new ABI version needed by LibreOffice 3.3.0 (don't run autoreconf which is not needed anymore)
* Wed Oct 22 2008 mrueckert@suse.de
- fix debug_packages_requires define
* Fri Aug  1 2008 ro@suse.de
- fix requires for debuginfo package
* Mon Jul 28 2008 mmarek@suse.cz
- update to 0.1.3
  * bugfixes
  * install-docs patch merged
* Fri Apr  4 2008 mmarek@suse.cz
- rename the library package to libwpg-0_1-1 as required by the
  policy (libwpg-0.1.so.1 -> libwpg-0_1-1)
- don't version the devel package after discussion with pmladek
  we'll do it only if the need arises
* Wed Apr  2 2008 mmarek@suse.cz
- packaged version 0.1.2, based on work by pmladek
